@@ -6,7 +6,7 @@
  * user information tests.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2011, 2012, 2013
+ * Copyright 2011, 2012, 2013, 2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
  * See LICENSE for licensing terms.
@@ -24,6 +24,7 @@
 #include <tests/tap/webauth.h>
 #include <webauth/basic.h>
 #include <webauth/keys.h>
+#include <webauth/krb5.h>
 #include <webauth/webkdc.h>
 
 /* Test cases to run without any local realms. */
@@ -538,6 +539,18 @@ static const struct wat_login_test tests_id_acl[] = {
 };
 
 
+/*
+ * Log callback, used to turn internal warning messages into diagnostics to
+ * make test failures easier to understand.
+ */
+static void
+log_callback(struct webauth_context *ctx UNUSED, void *data UNUSED,
+             const char *message)
+{
+    diag("%s", message);
+}
+
+
 int
 main(void)
 {
@@ -545,12 +558,16 @@ main(void)
     apr_array_header_t *local_realms, *permitted_realms;
     struct kerberos_config *krbconf;
     struct webauth_context *ctx;
+    struct webauth_krb5 *kc;
     struct webauth_keyring *ring;
     struct webauth_webkdc_config config;
     char *keyring, *tmpdir;
     int s;
     FILE *id_acl;
     size_t i;
+#ifdef HAVE_KRB5_GET_INIT_CREDS_OPT_SET_FAST_CCACHE_NAME
+    const char *cache;
+#endif
 
     /* Load the Kerberos configuration. */
     krbconf = kerberos_setup(TAP_KRB_NEEDS_BOTH);
@@ -569,6 +586,11 @@ main(void)
     if (webauth_context_init_apr(&ctx, pool) != WA_ERR_NONE)
         bail("cannot initialize WebAuth context");
 
+    /* Set log callbacks for info and higher. */
+    webauth_log_callback(ctx, WA_LOG_INFO, log_callback, NULL);
+    webauth_log_callback(ctx, WA_LOG_NOTICE, log_callback, NULL);
+    webauth_log_callback(ctx, WA_LOG_WARN, log_callback, NULL);
+
     /* Load the precreated keyring that we'll use for token encryption. */
     keyring = test_file_path("data/keyring");
     s = webauth_keyring_read(ctx, keyring, &ring);
@@ -665,6 +687,45 @@ main(void)
     is_int(WA_ERR_NONE, s, "Clearing id_acl_path succeeded");
     test_tmpdir_free(tmpdir);
 
+#ifdef HAVE_KRB5_GET_INIT_CREDS_OPT_SET_FAST_CCACHE_NAME
+    /*
+     * If built with FAST support, check if FAST actually works.  (It might
+     * not, even with FAST support in the build, if the KDC doesn't support
+     * FAST.)
+     */
+    cache = getenv("KRB5CCNAME");
+    if (cache == NULL)
+        bail("KRB5CCNAME not set after Kerberos initialization");
+    s = webauth_krb5_new(ctx, &kc);
+    if (s != WA_ERR_NONE)
+        bail("cannot initialize Kerberos: %s", webauth_error_message(ctx, s));
+    s = webauth_krb5_set_fast_armor_path(ctx, kc, cache);
+    if (s == WA_ERR_NONE)
+        s = webauth_krb5_init_via_password(ctx, kc, krbconf->userprinc,
+                                           krbconf->password, NULL,
+                                           krbconf->keytab,
+                                           krbconf->principal, NULL, NULL);
+    webauth_krb5_free(ctx, kc);
+
+    /*
+     * If FAST failed, skip the tests.  Otherwise, obtain a credential cache
+     * to use for FAST armor and then run the tests that assume no local realm
+     * again.  The authentications should then happen using FAST and succeed
+     * as before.
+     */
+    if (s != WA_ERR_NONE)
+        skip_block(2, "cannot authenticate with FAST");
+    else {
+        config.fast_armor_path = cache;
+        s = webauth_webkdc_config(ctx, &config);
+        if (s != WA_ERR_NONE)
+            diag("configuration failed: %s", webauth_error_message(ctx, s));
+        is_int(WA_ERR_NONE, s, "Setting fast_armor_path succeeded");
+        for (i = 0; i < ARRAY_SIZE(tests_no_local); i++)
+            run_login_test(ctx, &tests_no_local[i], ring, krbconf);
+    }
+#endif
+
     /* Clean up. */
     apr_terminate();
     return 0;
